@@ -20,7 +20,7 @@ def youtubeopen(text):
     import urllib.request
     import re
     import webbrowser
-    from PLManfred.say import *
+    from PLManfred.say import say
 
     text2 = text.replace(" ", "+").replace("?", "%3F")
 
